Handles MCP protocol requests and routes them to the appropriate server callbacks.
Summary
Functions
Handles an MCP request and returns a JSON-RPC response. Emits telemetry events for monitoring and metrics.
Handles MCP protocol requests and routes them to the appropriate server callbacks.
Handles an MCP request and returns a JSON-RPC response. Emits telemetry events for monitoring and metrics.